@@ -383,19 +383,21 @@ def filler(p, stream, dictionary, chunk_size, ic):
 
     """
     If no pattern has been found for a given range (i.e. pattern_position == -1)
-    Returns the Extension corresponding to the Full Sequence or the longest one
+    returns the Extension corresponding to the Full Sequence or the longest one
     possible multiple of 3.
     If a pattern has been found, return the corresponding extension.
     """
 
     if stream == 'up':
-        if p['up_start_pos'] == -1:
+        if p['up_start_pos'] == -1: 
             if p['Strand'] == '+':
-                return p['Initial_Start'] 
+                extension = p['Initial_Start'] # Extension to the edge
+                return extension - extension % 3 # Extension corrected
 
             elif p['Strand'] == '-':
-                return ( (dictionary[p['True_Chromosome']] - p['Initial_End']) -
-                       (dictionary[p['True_Chromosome']] % 3) )
+                extension = dictionary[p['True_Chromosome']] - p['Initial_End']
+                return extension - extension % 3
+
         else:
            return ( p['Effective_Extension_Length'] - 
                     p['up_start_pos'] + chunk_size * ic )
@@ -403,11 +405,13 @@ def filler(p, stream, dictionary, chunk_size, ic):
     elif stream == 'down':
         if p['down_stop_pos'] == -1:
             if p['Strand'] == '+': 
-                return ( (dictionary[p['True_Chromosome']] - p['Initial_End']) -
-                       (dictionary[p['True_Chromosome']] % 3) )
+                extension = dictionary[p['True_Chromosome']] - p['Initial_End']
+                return extension - extension % 3
 
             elif p['Strand'] == '-':
-                return p['Initial_Start'] 
+                 extension = p['Initial_Start']
+                 return extension - extension % 3 
+
         else:
             return ( p['down_stop_pos'] + chunk_size * ic )
 
